%define gitrev e35d145
%define gitdate 20161111
# Git repo: git://git.kernel.org/pub/scm/boot/dracut/dracut.git

# How to prepare the source archive from the git tree:
# $ hash=`git log -1 --format='%h'`
# $ date=`git log -1 --format='%cd' --date=short | tr -d -`
# $ git archive --prefix dracut-${date}-git${hash}/ ${hash} \
#	| xz -7e > ../dracut-${date}-git${hash}.tar.xz

%define dracutlibdir %{_prefix}/lib/dracut

Summary:	Next generation initrd image generator
Name:		dracut
Version:	044
Release:	%{gitdate}git.6
License:	GPLv2+
Group:		System/Base
Url:		https://dracut.wiki.kernel.org/
# http://git.kernel.org/cgit/boot/dracut/dracut.git/
#Source0:	http://www.kernel.org/pub/linux/utils/boot/dracut/%{name}-%{version}.tar.xz
Source0:	%{name}-%{gitdate}-git%{gitrev}.tar.xz
Source3:	01-rosa.conf

# ROSA-specific patches
Patch1006:	dracut-037-modprobe-loop.patch
Patch1009:	dracut-044-mount-live-rw-with-noatime.patch
Patch1010:	dracut-037-busybox-fallback-to-busybox.static-if-no-busybox.patch
Patch1011:	dracut-037-use-busybox--list.patch
Patch1013:	dracut-034-fix-prelink.patch
Patch1014:	dracut-037-always-define-vconsole-font.patch
Patch1015:	dracut-037-use-initrd-in-stead-of-initramfs-filename.patch
Patch1020:	dracut-041-plymouth-logo-file.patch
# Former dracut-027.minimal.patch: /dev/sdXn => /dev/sdX for the system
# images.
Patch1021:	dracut-041-fixup-boot-device.patch

# ? To send upstream?
Patch1022:	dracut-044-90crypt-use-uname.patch

Patch1023:	dracut-044-do-not-strip-binaries-by-default.patch

BuildRequires:	docbook-dtd45-xml
BuildRequires:	docbook-style-xsl
BuildRequires:	xsltproc
BuildRequires:	dash
BuildRequires:	bash
BuildRequires:	asciidoc
BuildRequires:	systemd-units
BuildRequires:	bash-completion
BuildRequires:	pkgconfig(libkmod)
BuildRequires:	pkgconfig(bash-completion)

Requires:	systemd >= 219
Requires(post):	systemd
%ifarch %{ix86} x86_64
Requires:	v86d
%endif
Provides:	mkinitrd-command
Requires(pre):	filesystem
Requires(pre):	coreutils
Suggests:	plymouth
Requires:	udev
Requires:	util-linux-ng
Requires:	kmod-compat
Requires:	e2fsprogs
Requires:	cpio
Requires:	findutils
Requires:	binutils
Requires:	grep
Requires:	mktemp
Requires:	bash
Requires:	dash
Requires:	kbd
Requires:	tar
Requires:	gzip
Requires:	bzip2
Requires:	xz
Requires:	file
Requires:	bridge-utils
#Requires:	bootloader-utils
Requires(post):	dmraid
Requires(post):	lvm2
Requires(post):	mdadm
Requires(pre):	rpm-helper
Requires(post,postun):	update-alternatives
Requires(post):	dracut-aufs

%description
Dracut contains tools to create a bootable initramfs for 2.6 Linux kernels.
Unlike existing implementations, dracut does hard-code as little as possible
into the initramfs. Dracut contains various modules which are driven by the
event-based udev. Having root on MD, DM, LVM2, LUKS is supported as well as
NFS, iSCSI, NBD, FCoE with the dracut-network package.

%prep
#setup -q
%setup -qn %{name}-%{gitdate}-git%{gitrev}
%apply_patches
# We don't want to strip dracut-install, that's debuginfo's job
sed -i -e 's,\$(strip),,g' install/Makefile


%build
%global optflags %{optflags} -Os
%serverbuild_hardened

# The build system sets CFLAGS overriding the default value dracut's Makefile
# uses. However, that default set of options also sets the path to libkmod
# headers. Add it here then.
export CFLAGS="%{optflags} $(pkg-config --cflags libkmod)"

%configure2_5x \
	--systemdsystemunitdir=%{_unitdir} \
	--bashcompletiondir=$(pkg-config --variable=completionsdir bash-completion) \
	--libdir=%{_prefix}/lib

%make CC=%{__cc}

%install
%makeinstall_std

# We place the distro-specific config in /usr/lib/dracut/dracut-conf.d/ 
# to make it overridable (the file with the same name in /etc/dracut.conf.d/
# has a higher priority).
install -m 644 %{SOURCE3} %{buildroot}%{dracutlibdir}/dracut.conf.d

echo "DRACUT_VERSION=%{version}-%{release}" > %{buildroot}%{dracutlibdir}/dracut-version.sh

# bluca remove patch backup files
find %{buildroot} -type f -name '*.orig' -exec rm {} \;
find %{buildroot} -type f -name '*~' -exec rm {} \;

# fix permission of module files
chmod +x %{buildroot}%{dracutlibdir}/modules.d/*/*.sh

mkdir -p %{buildroot}/boot/dracut
mkdir -p %{buildroot}%{_var}/lib/dracut/overlay
install -m 755 -d %{buildroot}%{_datadir}/dracut

mkdir -p %{buildroot}%{_sbindir}
mkdir -p %{buildroot}/sbin
mv %{buildroot}%{_bindir}/* %{buildroot}%{_sbindir}/

ln -s %{_sbindir}/dracut %{buildroot}%{_bindir}/dracut
ln -s %{_sbindir}/dracut %{buildroot}/sbin/dracut
ln -s %{dracutlibdir}/dracut-install %{buildroot}%{_sbindir}/dracut-install

mkdir -p %{buildroot}%{_localstatedir}/log
touch %{buildroot}%{_localstatedir}/log/dracut.log
mkdir -p %{buildroot}%{_sysconfdir}/logrotate.d
install -m 0644 dracut.logrotate %{buildroot}%{_sysconfdir}/logrotate.d/dracut

mv %{buildroot}%{_sbindir}/lsinitrd %{buildroot}%{_sbindir}/lsinitrd-dracut
mv %{buildroot}%{_sbindir}/mkinitrd %{buildroot}%{_sbindir}/mkinitrd-dracut

# (tpg) don't follow this usr madness
# systemctl sits in /bin, and it symlinks to /usr/bin
sed -i -e 's#/usr/bin/systemctl#/bin/systemctl#g' %{buildroot}%{dracutlibdir}/modules.d/*/*.service
# (tpg) use real path for udevadm
sed -i -e 's#/usr/bin/udevadm#/sbin/udevadm#g' %{buildroot}%{dracutlibdir}/modules.d/*/*.service

# (tpg) this conflicts with mkinitrd
rm -rf %{buildroot}%{_mandir}/man8/mkinitrd.8*

%pre
# Workaround for update from dracut 037 where "dmsquash-live" was in the
# list of modules to add. If the kernel is updated in the same transaction
# as dracut, the post scriptlet for the kernel would try to create initrd
# using both the new and the old dracut configurations. It would fail as a
# result and leave the system without initrd.
if test -e /etc/dracut.conf.d/50-dracut-rosa.conf; then
    sed -i -e 's/dmsquash-live//' /etc/dracut.conf.d/50-dracut-rosa.conf
fi

%post
update-alternatives --install /sbin/mkinitrd mkinitrd %{_sbindir}/mkinitrd-dracut 110 || :
update-alternatives --install /sbin/lsinitrd lsinitrd %{_sbindir}/lsinitrd-dracut 110 || :

%postun
[ ! -e /usr/sbin/mkinitrd-dracut ] && update-alternatives --remove mkinitrd %{_sbindir}/mkinitrd-dracut || :
[ ! -e /usr/sbin/lsinitrd-dracut ] && update-alternatives --remove lsinitrd %{_sbindir}/lsinitrd-dracut || :

%posttrans
# Workaround for update from dracut-0.17 with broken postun script (which could incorrectly remove mkinitrd and lsinitrd symlinks)
[ -e /usr/sbin/mkinitrd-dracut ] && [ ! -e /sbin/mkinitrd ] && update-alternatives --install /sbin/mkinitrd mkinitrd %{_sbindir}/mkinitrd-dracut 110 || :
[ -e /usr/sbin/lsinitrd-dracut ] && [ ! -e /sbin/lsinitrd ] && update-alternatives --install /sbin/lsinitrd lsinitrd %{_sbindir}/lsinitrd-dracut 110 || :

# Regenerate the initrd here rather than in post because the old configs
# can interfere then. Dracut 037 had erroneously left "dmsquash-live" in
# the list of modules, which lead to scriptlet failures during the update.
if [ -d /lib/modules/$(uname -r) ]; then
    %{_sbindir}/dracut -f /boot/initrd-$(uname -r).img $(uname -r)
fi

%files
%doc README.generic README.modules README.kernel HACKING TODO AUTHORS
%dir /boot/dracut
%dir %{_datadir}/dracut
%dir %{_var}/lib/dracut
%dir %{_var}/lib/dracut/overlay
%dir %{dracutlibdir}/modules.d
%dir %{_prefix}/lib/kernel/install.d
%dir %{dracutlibdir}/dracut.conf.d
%dir %{_sysconfdir}/dracut.conf.d
%config %{_sysconfdir}/dracut.conf
%config %{_sysconfdir}/logrotate.d/dracut
%attr(0644,root,root) %ghost %config(missingok,noreplace) %{_localstatedir}/log/dracut.log
%{dracutlibdir}/dracut.conf.d/01-rosa.conf
/sbin/dracut
%{_sbindir}/dracut
%{_bindir}/dracut
%{_sbindir}/dracut-catimages
%{_sbindir}/dracut-install
%{_sbindir}/lsinitrd-dracut
%{_sbindir}/mkinitrd-dracut
%{_unitdir}/*.service
%{_unitdir}/*/*.service
%{_prefix}/lib/kernel/install.d/5*-dracut*.install
%{dracutlibdir}/skipcpio
%{dracutlibdir}/dracut-install
%{dracutlibdir}/dracut-version.sh
%{dracutlibdir}/dracut-functions.sh
%{dracutlibdir}/dracut-functions
%{dracutlibdir}/modules.d/*
%{dracutlibdir}/dracut-initramfs-restore
%{dracutlibdir}/dracut-logger.sh
%{dracutlibdir}/dracut-init.sh
%{_datadir}/bash-completion/completions/dracut
%{_datadir}/bash-completion/completions/lsinitrd
%{_mandir}/man1/lsinitrd.1.*
%{_mandir}/man5/dracut.conf.5*
%{_mandir}/man7/dracut.bootup.7*
%{_mandir}/man7/dracut.kernel.7*
%{_mandir}/man7/dracut.cmdline.7*
%{_mandir}/man7/dracut.modules.7*
%{_mandir}/man8/dracut*.8*
%{_mandir}/man8//mkinitrd-suse.8*
%{_datadir}/pkgconfig/dracut.pc

%changelog

* Thu Apr 26 2018 Evgenii Shatokhin <eugene.shatokhin@rosalab.ru> 044-20161111git.6
- (130e5b2) Release up

* Thu Apr 26 2018 Evgenii Shatokhin <eugene.shatokhin@rosalab.ru> 044-20161111git.5
- (17a5f3c) Build generic (rather than host-only) initrd by default
- (17a5f3c) Host-only mode used to be the default one, but dracut kept omitting
- (17a5f3c) needed kernel modules (and picking unnecessary ones like the proprietary
- (17a5f3c) graphics drivers) in many cases then. For example, if 'ahci' was built
- (17a5f3c) as a module, it did not make it into the initrds. As a result, many
- (17a5f3c) systems would not find their disks at initrd stage and failed to boot
- (17a5f3c) with not so obvious errors.
- (17a5f3c) Maintaining the list of additional drivers to include is a pain.
- (17a5f3c) Let us just use the generic initrds instead. They are larger, 60-65 Mb VS
- (17a5f3c) 12-15 Mb for a hostonly initrd on my systems, but should be more
- (17a5f3c) reliable.
- (17a5f3c) If disk space becomes a problem, the user could try removing the older
- (17a5f3c) kernels along with their initrds: urpm-package-cleanup --oldkernels.
- (17a5f3c) Generic initrds might also open a way to provide the pre-built initrds
- (17a5f3c) to the users rather than to rebuild them on the users' machines each
- (17a5f3c) time. Such rebuilds are also error-prone. Not sure if it is possible to
- (17a5f3c) use the pre-built initrds now, that should be investigated later.
- (Evgenii Shatokhin: bc27651) Do not strip kernel modules by default
- (Evgenii Shatokhin: bc27651) Unless this is a custom-built kernel, the modules have already been
- (Evgenii Shatokhin: bc27651) stripped when the kernel packages were built.
- (Evgenii Shatokhin: bc27651) Besides, if the user does choose to strip the files in the initrd, make
- (Evgenii Shatokhin: bc27651) sure to get the signature properly, without null symbols. Otherwise,
- (Evgenii Shatokhin: bc27651) bash may complain like this when processing "SIG=$(tail -c 28 "$f")":
- (Evgenii Shatokhin: bc27651) "warning: command substitution: ignored null byte in input"

* Thu Dec 01 2016 Evgenii Shatokhin <eugene.shatokhin@rosalab.ru> 044-20161111git.4
- (d6fd127) Make the config closer to the defaults, do not meddle with drivers
- (d6fd127) "add_drivers" has now (v044+, may be true for earlier versions as well)
- (d6fd127) an unfortunate side effect. If it is used, the default set of drivers
- (d6fd127) is not included into initrd.
- (d6fd127) So either we do not use add_drivers at all or specify all the defaults
- (d6fd127) manually (e.g. "xhci-hcd xhci-pci xhci-plat-hcd", etc.)
- (d6fd127) I chose the first option: do not use add_drivers & Ko.
- (d6fd127) See the code in modules.d/90kernel-modules/module-setup.sh for the list
- (d6fd127) of the defaults.

* Thu Dec 01 2016 Evgenii Shatokhin <eugene.shatokhin@rosalab.ru> 044-20161111git.3
- (233f1c8) Fix: 90crypt: ROSA does not have 'arch' utility

* Wed Nov 30 2016 Evgenii Shatokhin <eugene.shatokhin@rosalab.ru> 044-20161111git.2
- (adf87af) Release up

* Wed Nov 30 2016 Evgenii Shatokhin <eugene.shatokhin@rosalab.ru> 044-20161111git.1
- (1d73938) conf: Do not force inclusion of ext3 module (attempt #3)
- (1d73938) Kernel 4.2+ no longer has ext3, ext4 is used instead.
- (1d73938) ext4 is built into our kernel, by the way.
- (1d73938) This gets rid of the errors like "Failed to install module ext3" when
- (1d73938) generating initrd.
- (1d73938) Notes for the attempt #3:
- (1d73938) I tried at least twice to get rid of ext3 before but the ISO images of
- (1d73938) ROSA failed to build with strange errors. Let us fix the build system
- (1d73938) this time.
- (Evgenii Shatokhin: 98b8492) Updated to git rev. e35d145 (2016-11-11)
- (Evgenii Shatokhin: 98b8492) Removed unneeded stuff and already applied patches as well.

* Fri Oct 14 2016 Andrey Bondrov <andrey.bondrov@rosalab.ru> 041-17
- (57bb4e0) MassBuild#1169: Increase release tag

* Tue Sep 20 2016 Andrey Bondrov <andrey.bondrov@rosalab.ru> 041-16
- (468b046) Add patch with bash 4.4 support

* Thu Sep 15 2016 Evgenii Shatokhin <eugene.shatokhin@rosalab.ru> 041-15
- (88e8525) Release up + removed unused patches

* Thu Sep 15 2016 Evgenii Shatokhin <eugene.shatokhin@rosalab.ru> 041-14
- (ebf35c3) Revert "Sync with working copy from rosa2014.1 for now"
- (ebf35c3) This reverts commit b7e79adbcd6bce494edceb2c068dfe6edcd62497.

* Wed Aug 31 2016 Andrey Bondrov <andrey.bondrov@rosalab.ru> 041-12
- (b7e79ad) Sync with working copy from rosa2014.1 for now

* Tue Aug 09 2016 Evgenii Shatokhin <eugene.shatokhin@rosalab.ru> 041-14
- (4d5542c) Release up

* Tue Aug 09 2016 Evgenii Shatokhin <eugene.shatokhin@rosalab.ru> 041-13
- (92e635b) Revert "conf: Do not force inclusion of ext3 module"
- (92e635b) This reverts commit 93b923a815f414b5a479bb4219a13da982de8c85.
- (92e635b) The Live CD system still needs ext3 for the kernel 4.1.x at least. We
- (92e635b) need to migrate to ext4 there first.
- (Evgenii Shatokhin: 072d143) Enable early loading of CPU microcode
- (Evgenii Shatokhin: 072d143) Intel and AMD CPUs are currently based on RISC chips with the special
- (Evgenii Shatokhin: 072d143) microcode that actually implements the x86 instruction set.
- (Evgenii Shatokhin: 072d143) The updates for such microcode are often included into BIOS updates, but
- (Evgenii Shatokhin: 072d143) it is not always the case.
- (Evgenii Shatokhin: 072d143) The kernel may apply such updates itself to fix bugs, etc. This should
- (Evgenii Shatokhin: 072d143) be done as early at boot as possible, so enable the support for it in
- (Evgenii Shatokhin: 072d143) dracut by default.

* Tue Aug 09 2016 Evgenii Shatokhin <eugene.shatokhin@rosalab.ru> 041-12
- (93b923a) conf: Do not force inclusion of ext3 module
- (93b923a) Kernel 4.2+ no longer has ext3, ext4 is used instead.
- (93b923a) ext4 is built into our kernel, by the way.
- (93b923a) This gets rid of the errors like "Failed to install module ext3" when
- (93b923a) generating initrd.
- (Evgenii Shatokhin: ab28c79) Updated to 041-12

* Tue Dec 01 2015 Evgenii Shatokhin <eugene.shatokhin@rosalab.ru> 041-11
- (f430289) Do not include asus-nb-wmi into initrd
- (f430289) I doubt this "Asus Notebooks WMI Hotkey Driver" is needed at the initrd
- (f430289) stage on all machines.
- (f430289) If it is, we can re-add it later.
- (Evgenii Shatokhin: dcf6761) conf: Removed duplicate and built-in modules
- (Evgenii Shatokhin: dcf6761) ahci and ext4 are built-in.
- (Evgenii Shatokhin: dcf6761) isofs is an alias for iso9660.
- (Evgenii Shatokhin: 4db0b68) Added the modules for USB3 support and for some Logitech devices
- (Evgenii Shatokhin: 4db0b68) http://bugs.rosalinux.ru/show_bug.cgi?id=6381
- (Eugene Shatokhin: 2090b8b) Release up

* Tue Jun 23 2015 Eugene Shatokhin <eugene.shatokhin@rosalab.ru> 041-10
- (1c3e094) Require mdadm: it is needed for 'mdraid' dracut module
- (Eugene Shatokhin: f22ba5a) Release up

* Tue Jun 23 2015 Eugene Shatokhin <eugene.shatokhin@rosalab.ru> 041-9
- (10a0bc5) Require lvm2: it is also needed by the time dracut starts creating initrd
- (Eugene Shatokhin: a4d9f18) Release up

* Mon Jun 22 2015 Eugene Shatokhin <eugene.shatokhin@rosalab.ru> 041-8
- (e64e902) Added a workaround for update from dracut 037
- (e64e902) Dracut 037 erroneously has "dmsquash-live" in the list of modules to add
- (e64e902) and leaves hostonly=yes. These two settings conflict with each other in
- (e64e902) dracut 041.
- (e64e902) Most of the time it would not be a problem but if the kernel is updated
- (e64e902) in the same transaction as dracut, the post scriptlet for the kernel would
- (e64e902) try to create initrd using both the new and the old dracut configurations.
- (e64e902) It would fail as a result and leave the system without initrd.
- (e64e902) Added a hack to mitigate this problem.
- (Eugene Shatokhin: 1eba9ef) Added a few fixes to rosa2014.1 branch
- (Eugene Shatokhin: 1eba9ef) * Fixed boot in live mode on 32-bit systems, see
- (Eugene Shatokhin: 1eba9ef) dracut-041-fixup-boot-device.patch.
- (Eugene Shatokhin: 1eba9ef) * In case the updates for both systemd and dracut are installed at the
- (Eugene Shatokhin: 1eba9ef) same time, make sure systemd is updated first. This way, the new files
- (Eugene Shatokhin: 1eba9ef) for systemd will be included into the initrd image dracut will create in
- (Eugene Shatokhin: 1eba9ef) %post.
- (Eugene Shatokhin: 4dd5adf) Fixed the patch: the device may be passed not as /dev/sdXn
- (Eugene Shatokhin: 4dd5adf) Looks like /dev/disk/by-label/... is currently used, so we need to
- (Eugene Shatokhin: 4dd5adf) canonicalize the path first.
- (Eugene Shatokhin: 9c2b164) Make sure systemd is updated before dracut starts creating initrd images
- (Eugene Shatokhin: 9c2b164) systemd and some related files are included into the initrd images. So the
- (Eugene Shatokhin: 9c2b164) correct version must be installed before dracut starts its job.
- (Eugene Shatokhin: a14a17f) Restored and re-diffed a patch to fix boot in Live mode on x32
- (Eugene Shatokhin: a14a17f) Details: http://bugs.rosalinux.ru/show_bug.cgi?id=5768#c3

* Fri Jun 12 2015 Eugene Shatokhin <eugene.shatokhin@rosalab.ru> 041-7
- (49c5c57) Make sure dmraid is installed before %post, etc.
- (Eugene Shatokhin: abc1587) Require 'dmraid'
- (Eugene Shatokhin: abc1587) Our configuration for dracut states it should use 'dmraid'. However,
- (Eugene Shatokhin: abc1587) dracut refuses to do so if 'dmraid' executable is missing, so the
- (Eugene Shatokhin: abc1587) installation scriptlets may fail. Adding a dependency to fix that.
- (Eugene Shatokhin: abc1587) Note that dmraid is installed in ROSA Fresh by default, so the users
- (Eugene Shatokhin: abc1587) could only experience problems if they removed it manually. Anyway,
- (Eugene Shatokhin: abc1587) it is better to make it more reliable.

* Wed Jun 10 2015 Eugene Shatokhin <eugene.shatokhin@rosalab.ru> 041-6
- (b89fbf2) Rediffed 'include-hyperv_fb' patch for version 041
- (Eugene Shatokhin: ce11908) Merged changes from import/dracut

* Thu May 14 2015 Eugene Shatokhin <eugene.shatokhin@rosalab.ru> 041-5
- (ab290b2) Regenerate initrd in %posttrans rather than in %post
- (ab290b2) This is to make sure the old dracut configs do not interfere (in case
- (ab290b2) they have been moved or renamed by this update).
- (ab290b2) Dracut 037 had erroneously left "dmsquash-live" in the list of modules,
- (ab290b2) which lead to scriptlet failures during the update.
- (Eugene Shatokhin: 443a401) Merged recent changes from import/dracut

* Fri May 08 2015 Eugene Shatokhin <eugene.shatokhin@rosalab.ru> 041-4
- (45d176e) Added spaces at the ends of the lists, may help concatenation
- (Eugene Shatokhin: d199242) Make sure ROSA-specific config is overridable
- (Eugene Shatokhin: d199242) 1. The config is now placed in /usr/lib/dracut/dracut.conf.d/, which
- (Eugene Shatokhin: d199242) allows to override it with a file in /etc/dracut.conf.d/ having the same
- (Eugene Shatokhin: d199242) name.
- (Eugene Shatokhin: d199242) 2. The config was renamed from 50-dracut-rosa.conf to 01-rosa.conf to
- (Eugene Shatokhin: d199242) allow 02livecd.conf (used for building live images) to override settings
- (Eugene Shatokhin: d199242) in it. "hostonly" being the most important one in this case.
- (Eugene Shatokhin: d199242) Otherwise, "hostonly" would remain as "yes", which is not suitable for
- (Eugene Shatokhin: d199242) live images.

* Thu May 07 2015 Eugene Shatokhin <eugene.shatokhin@rosalab.ru> 041-3
- (bcfa0bb) Release up

* Thu May 07 2015 Eugene Shatokhin <eugene.shatokhin@rosalab.ru> 041-2
- (3a6bb04) Do not install 'dmsquash-live' if hostonly is 'yes'
- (Eugene Shatokhin: c7325f6) Do not install 'ifcfg' module, it depends on 'network'
- (Eugene Shatokhin: a5d8fd8) Do not set early_microcode="yes"
- (Eugene Shatokhin: a5d8fd8) Our kernels do not support that yet.

* Thu May 07 2015 Eugene Shatokhin <eugene.shatokhin@rosalab.ru> 041-1
- (5709163) Cherry-picked part of commit 004fb182 from import/dracut
- (5709163) 004fb18266d3b2814fd3348b3f2aaa14bec202c2
- (5709163) "Remove default vconsole.conf before installing system one"
- (Eugene Shatokhin: c8a1dcf) Removed excessive requirements
- (Eugene Shatokhin: cf0c00d) Removed uvesafb-related stuff (obsolete)
- (Eugene Shatokhin: 750a216) Updated to version 041, revisited the patchset
- (Eugene Shatokhin: 750a216) * Updated a few patches based on what is done in OMV.
- (Eugene Shatokhin: 750a216) * Moved setting PLYMOUTH_LOGO_FILE to a separate patch.
- (Eugene Shatokhin: 750a216) * Added patches from Fedora that may help alleviate the problems with
- (Eugene Shatokhin: 750a216) DeviceMapper and provide other fixes.
- (Eugene Shatokhin: 750a216) * Disabled a couple patches.


